@@ -13,6 +13,14 @@ public:
     unsigned int index);
 };
 
+class AdmiralTV2: public PIRKeysetMetaData
+{
+public:
+  AdmiralTV2(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class AdmiralVCR1: public PIRKeysetMetaData
 {
 public:
