@@ -26,6 +26,7 @@
 #include "keysets/hauppauge.h"
 #include "keysets/hitachi.h"
 #include "keysets/homecast.h"
+#include "keysets/huawei.h"
 #include "keysets/jvc.h"
 #include "keysets/kenwood.h"
 #include "keysets/lg.h"
@@ -34,6 +35,7 @@
 #include "keysets/mce.h"
 #include "keysets/mitsubishi.h"
 #include "keysets/nokia.h"
+#include "keysets/onida.h"
 #include "keysets/panasonic.h"
 #include "keysets/philco.h"
 #include "keysets/philips.h"
@@ -52,6 +54,9 @@
 #include "keysets/tivo.h"
 #include "keysets/topfield.h"
 #include "keysets/toshiba.h"
+#include "keysets/vestel.h"
+#include "keysets/virgin.h"
+#include "keysets/vizio.h"
 #include "keysets/wd.h"
 #include "keysets/westinghouse.h"
 #include "keysets/yamaha.h"
@@ -218,6 +223,9 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new HomecastReceiver1(guiObject, counter++));
   populateKeyset(new HomecastReceiver2(guiObject, counter++));
 
+  populateKeyset(new HuaweiSTB1(guiObject, counter++));
+  populateKeyset(new HuaweiSTB2(guiObject, counter++));
+
   populateKeyset(new JVCSat1(guiObject, counter++));
   populateKeyset(new JVCSat2(guiObject, counter++));
   populateKeyset(new JVCVCR1(guiObject, counter++));
@@ -283,6 +291,9 @@ PIRKeysetManager::PIRKeysetManager(
 
   populateKeyset(new NokiaGenericVCR(guiObject, counter++));
 
+  populateKeyset(new OnidaTV1(guiObject, counter++));
+  populateKeyset(new OnidaDVD1(guiObject, counter++));
+
   populateKeyset(new PanasonicCarAudio(guiObject, counter++));
   populateKeyset(new PanasonicSat1(guiObject, counter++));
   populateKeyset(new PanasonicSat1a(guiObject, counter++));
@@ -417,6 +428,7 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new SharpTV1e(guiObject, counter++));
   populateKeyset(new SharpVCR1(guiObject, counter++));
   populateKeyset(new SharpReceiver1(guiObject, counter++));
+  populateKeyset(new SharpAC1(guiObject, counter++));
 
   populateKeyset(new SkyReceiver1(guiObject, counter++));
   populateKeyset(new SkyReceiver1a(guiObject, counter++));
@@ -465,6 +477,13 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new ToshibaDisc1c(guiObject, counter++));
   populateKeyset(new ToshibaDisc1d(guiObject, counter++));
 
+  populateKeyset(new VestelTV1(guiObject, counter++));
+  populateKeyset(new VestelTV2(guiObject, counter++));
+
+  populateKeyset(new VirginSTB1(guiObject, counter++));
+
+  populateKeyset(new VizioTV1(guiObject, counter++));
+
   populateKeyset(new WDMediaPlayer1(guiObject, counter++));
   populateKeyset(new WDMediaPlayer1a(guiObject, counter++));
 
