@@ -28,6 +28,7 @@ enum PIRMakeName{
   Hauppauge_Make,
   Hitachi_Make,
   Homecast_Make,
+  Huawei_Make,
   JVC_Make,
   Kenwood_Make,
   LG_Make,
@@ -36,6 +37,7 @@ enum PIRMakeName{
   Microsoft_Make,
   Mitsubishi_Make,
   Nokia_Make,
+  Onida_Make,
   Panasonic_Make,
   Philco_Make,
   Philips_Make,
@@ -54,6 +56,9 @@ enum PIRMakeName{
   Tivo_Make,
   Topfield_Make,
   Toshiba_Make,
+  Vestel_Make,
+  Virgin_Make,
+  Vizio_Make,
   WD_Make,
   Westinghouse_Make,
   Yamaha_Make,
